==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_new.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 

/* ==================================================================== */
// 
// token = setrandvar_new ( )
//   creates a new set of random variables
// token = setrandvar_new ( n ) 
//   creates a new set of n uniformly distributed random variables
// token = setrandvar_new ( file ) 
//   creates a new set of random variables from a file
//
int sci_setrandvar_new (char *fname)
{
	int token;
	int nbvars;
	char * file = NULL;
	SetRandomVariable * srv = NULL;

	CheckRhs(0,1) ;
	CheckLhs(1,1) ;
	if ( Rhs == 1 ) 
	{
		if ( GetType(1) == sci_matrix )		{
			// token = sci_setrandvar_new ( n ) 
			nisp_GetOneInteger ( fname , 1 , &nbvars );
		} 
		else if ( GetType(1) == sci_strings )		{
			// token = sci_setrandvar_new ( file ) 
			nisp_GetOneChar ( fname , 1 , &file );
		} else {
			// The 1st parameter is unknown
			Scierror(204,_("%s: Wrong type for input argument #%d: Double or string expected.\n"),fname,1);
			return 0;
		}
	}
	if ( Rhs == 0 ) {
		// token = sci_setrandvar_new ( )
		srv = new SetRandomVariable ( );
	} else if ( Rhs == 1 ) {
		if ( GetType(1) == sci_matrix ) {
			// token = sci_setrandvar_new ( n ) 
			srv = new SetRandomVariable ( nbvars );
		} else if ( GetType(1) == sci_strings ) {
			// token = sci_setrandvar_new ( file ) 
			srv = new SetRandomVariable ( file );
		}
	}
	token = nisp_SetRandomVariable_map_add ( srv );
	nisp_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_new.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 

/* ==================================================================== */
// 
// token = setrandvar_new ( )
//   creates a new set of random variables
// token = setrandvar_new ( n ) 
//   creates a new set of n uniformly distributed random variables
// token = setrandvar_new ( file ) 
//   creates a new set of random variables from a file
//
int sci_setrandvar_new (char *fname)
{
	int token;
	int nbvars;
	char * file = NULL;
	SetRandomVariable * srv = NULL;

	CheckRhs(0,1) ;
	CheckLhs(1,1) ;
	if ( Rhs == 1 ) 
	{
		if ( GetType(1) == sci_matrix )		{
			nispgw_GetOneInteger ( fname , 1 , &nbvars );
		} 
		else if ( GetType(1) == sci_strings )		{
			nispgw_GetOneChar ( fname , 1 , &file );
		} else {
			// The 1st parameter is unknown
			Scierror(204,_("%s: Wrong type for input argument #%d: Double or string expected.\n"),fname,1);
			return 0;
		}
	}
	if ( Rhs == 0 ) {
		srv = new SetRandomVariable ( );
	} else if ( Rhs == 1 ) {
		if ( GetType(1) == sci_matrix ) {
			srv = new SetRandomVariable ( nbvars );
		} else if ( GetType(1) == sci_strings ) {
			srv = new SetRandomVariable ( file );
		}
	}
	token = nisp_SetRandomVariable_map_add ( srv );
	nispgw_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */
